import React from 'react';
/**
 * @memberof InfoBox
 * @alias InfoBoxProps
 */
export declare type InfoBoxProps = {
    /** Title of an InfoBox */
    title: string;
    /** Inner content - usually couple of {@link Text} nodes */
    children: React.ReactNode;
    /** Optional testId */
    testId?: string;
};
/**
 * @class
 * Used for all type of information like:
 *
 * > you don't have x - please add first one"
 *
 * in the system.
 *
 * Usage:
 * ```javascript
 * import { InfoBox, InfoBoxProps } from 'admin-bro'
 * ```
 *
 * @component
 * @subcategory Molecules
 * @example
 * return (
 * <InfoBox title="There are no cars in the system">
 *   <Text>Currently there are no cars in the system</Text>
 *   <Text>To create first click</Text>
 *   <Button mt="lg"><Icon icon="Add" />Create</Button>
 * </InfoBox>
 * )
 */
export declare const InfoBox: React.FC<InfoBoxProps>;
export default InfoBox;
